export const creatGithubProfileUrl = (handle: string) => {
  return 'https://github.com/' + handle;
};

export const creatTwitterProfileUrl = (handle: string) => {
  return 'https://twitter.com/' + handle;
};

export const creatLinkedinProfileUrl = (handle: string) => {
  return 'https://www.linkedin.com/in/' + handle;
};
