export const navBarHeight = undefined;
export const bodyMinHeight = '60.4rem';
export const bodySubComponentMinHeight = '45vh';
export const bodyWidth = '60rem';
export const footerHeight = undefined;
